#!/bin/sh
BINDIR="$(dirname $0)"
MODELSDIR="${BINDIR}/models"
MODELNAME="$(basename $0)"
export LD_LIBRARY_PATH=${BINDIR}/../fmtplib:${BINDIR}/../python/lib:$LD_LIBRARY_PATH
export PYTHONHOME=${BINDIR}/../python
exec $MODELSDIR/$MODELNAME "$@"
